@@ -15,15 +15,12 @@ use base qw(Exporter);
 
 our @EXPORT_OK = ();
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 #{{{sub new
 sub new {
     my ( $class, $nakamura ) = @_;
 
-    # Set the Referer to /dev/integrationtests in order to be
-    # allowed to post to the Sakai Nakamura instance:
-    ${$nakamura}->{'Referer'} = '/dev/integrationtests';
     my $authn = $class->SUPER::new($nakamura);
     ${$nakamura}->{'Authn'} = \$authn;
     bless $authn, $class;
