@@ -9,8 +9,9 @@ use Carp;
 use JSON;
 use Getopt::Long qw(:config bundling);
 use Pod::Usage;
-use Sakai::Nakamura::ContentUtil;
 use Sakai::Nakamura;
+use Sakai::Nakamura::Authn;
+use Sakai::Nakamura::ContentUtil;
 
 use base qw(Apache::Sling::Content);
 
@@ -20,7 +21,7 @@ use base qw(Exporter);
 
 our @EXPORT_OK = qw(run);
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 #{{{sub new
 sub new {
@@ -38,36 +39,13 @@ sub new {
 
 #}}}
 
-#{{{sub command_line
+#{{{ sub command_line
 sub command_line {
-    my ( $content, @ARGV ) = @_;
-
-    # options parsing
+    my ( $class, @ARGV ) = @_;
     my $nakamura = Sakai::Nakamura->new;
-    my $config   = config($nakamura);
-
-    GetOptions(
-        $config,              'auth=s',
-        'help|?',             'log|L=s',
-        'man|M',              'pass|p=s',
-        'threads|t=s',        'url|U=s',
-        'user|u=s',           'verbose|v+',
-        'add|a',              'additions|A=s',
-        'copy|c',             'delete|d',
-        'exists|e',           'filename|n=s',
-        'local|l=s',          'move|m',
-        'property|P=s',       'remote|r=s',
-        'remote-source|S=s',  'replace|R',
-        'view|V',             'view-copyright=s',
-        'view-description=s', 'view-tags=s',
-        'view-title=s',       'view-visibility=s'
-    ) or $content->help();
-
-    if ( $nakamura->{'Help'} ) { $content->help(); }
-    if ( $nakamura->{'Man'} )  { $content->man(); }
-
-    $content->run( $nakamura, $config );
-    return 1;
+    my $config   = $class->config( $nakamura, @ARGV );
+    my $authn    = new Sakai::Nakamura::Authn( \$nakamura );
+    return $class->run( $nakamura, $config );
 }
 
 #}}}
@@ -101,18 +79,47 @@ sub comment_add {
 #{{{sub config
 
 sub config {
-    my ($class) = @_;
+    my ( $class, $nakamura, @ARGV ) = @_;
+    my $content_config = $class->config_hash( $nakamura, @ARGV );
+
+    GetOptions(
+        $content_config,      'auth=s',
+        'help|?',             'log|L=s',
+        'man|M',              'pass|p=s',
+        'threads|t=s',        'url|U=s',
+        'user|u=s',           'verbose|v+',
+        'add|a',              'additions|A=s',
+        'copy|c',             'delete|d',
+        'exists|e',           'filename|n=s',
+        'local|l=s',          'move|m',
+        'property|P=s',       'remote|r=s',
+        'remote-source|S=s',  'replace|R',
+        'view|V',             'view-copyright=s',
+        'view-description=s', 'view-tags=s',
+        'view-title=s',       'view-visibility=s'
+    ) or $class->help();
+
+    return $content_config;
+}
+
+#}}}
+
+#{{{sub config_hash
+
+sub config_hash {
+    my ( $class, $nakamura, @ARGV ) = @_;
     my $view_copyright;
     my $view_description;
     my $view_tags;
     my $view_title;
     my $view_visibility;
-    my $content_config = $class->SUPER::config();
+    my $content_config = $class->SUPER::config_hash( $nakamura, @ARGV );
     $content_config->{'view-copyright'}   = \$view_copyright;
     $content_config->{'view-description'} = \$view_description;
     $content_config->{'view-tags'}        = \$view_tags;
     $content_config->{'view-title'}       = \$view_title;
     $content_config->{'view-visibility'}  = \$view_visibility;
+
     return $content_config;
 }
 
@@ -182,7 +189,9 @@ sub run {
 
     my $success = 1;
 
-    if ( defined ${ $config->{'additions'} } ) {
+    if    ( $nakamura->{'Help'} ) { $content->help(); }
+    elsif ( $nakamura->{'Man'} )  { $content->man(); }
+    elsif ( defined ${ $config->{'additions'} } ) {
         my $message =
           "Adding content from file \"" . ${ $config->{'additions'} } . "\":\n";
         Apache::Sling::Print::print_with_lock( "$message", $nakamura->{'Log'} );
