@@ -6,6 +6,7 @@ use 5.008008;
 use strict;
 use warnings;
 use Carp;
+use Getopt::Long qw(:config bundling);
 use base qw(Apache::Sling::User);
 use Sakai::Nakamura;
 use Sakai::Nakamura::Authn;
@@ -17,7 +18,7 @@ use base qw(Exporter);
 
 our @EXPORT_OK = ();
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 #{{{sub check_exists
 sub check_exists {
@@ -37,21 +38,59 @@ sub check_exists {
 
 #}}}
 
+#{{{ sub command_line
+sub command_line {
+    my ( $class, @ARGV ) = @_;
+    my $nakamura = Sakai::Nakamura->new;
+    my $config   = $class->config( $nakamura, @ARGV );
+    my $authn    = new Sakai::Nakamura::Authn( \$nakamura );
+    return $class->run( $nakamura, $config );
+}
+
+#}}}
+
 #{{{sub config
 
 sub config {
-    my ($class) = @_;
+    my ( $class, $nakamura, @ARGV ) = @_;
+    my $user_config = $class->config_hash( $nakamura, @ARGV );
+
+    GetOptions(
+        $user_config,          'auth=s',
+        'help|?',              'log|L=s',
+        'man|M',               'pass|p=s',
+        'threads|t=s',         'url|U=s',
+        'user|u=s',            'verbose|v+',
+        'add|a=s',             'additions|A=s',
+        'change-password|c=s', 'delete|d=s',
+        'email|E=s',           'first-name|f=s',
+        'exists|e=s',          'last-name|l=s',
+        'new-password|n=s',    'password|w=s',
+        'property|P=s',        'update=s',
+        'view|V=s'
+    ) or $class->help();
+
+    return $user_config;
+}
+
+#}}}
+
+#{{{sub config_hash
+
+sub config_hash {
+    my ( $class, $nakamura, @ARGV ) = @_;
     my $me;
     my $profile_field;
     my $profile_section;
     my $profile_update;
     my $profile_value;
-    my $user_config = $class->SUPER::config();
+    my $user_config = $class->SUPER::config_hash( $nakamura, @ARGV );
     $user_config->{'me'}              = \$me;
     $user_config->{'profile-field'}   = \$profile_field;
     $user_config->{'profile-section'} = \$profile_section;
     $user_config->{'profile-update'}  = \$profile_update;
     $user_config->{'profile-value'}   = \$profile_value;
+
     return $user_config;
 }
 
@@ -110,7 +149,9 @@ sub run {
 
     my $success = 1;
 
-    if ( defined ${ $config->{'exists'} } ) {
+    if    ( $nakamura->{'Help'} ) { $user->help(); }
+    elsif ( $nakamura->{'Man'} )  { $user->man(); }
+    elsif ( defined ${ $config->{'exists'} } ) {
         $authn->login_user();
         my $user = new Sakai::Nakamura::User( \$authn, $nakamura->{'Verbose'},
             $nakamura->{'Log'} );
